pub type FieldList = Vec<(&'static str, FieldValue)>;Expand description
A field list small enough to keep inline for the typical span. Spans or events with > 8 fields spill to the heap.
Aliased Type
pub struct FieldList { /* private fields */ }pub type FieldList = Vec<(&'static str, FieldValue)>;A field list small enough to keep inline for the typical span. Spans or events with > 8 fields spill to the heap.
pub struct FieldList { /* private fields */ }